==> activemq-parent-5.19.1-source-release.zip: activemq-parent-5.19.1/activemq-tooling/activemq-perf-maven-plugin/src/main/java/org/apache/activemq/tool/AbstractJmsMeasurableClient.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.tool;

import java.util.concurrent.atomic.AtomicLong;

import javax.jms.ConnectionFactory;

import org.apache.activemq.tool.sampler.MeasurableClient;

public abstract class AbstractJmsMeasurableClient extends AbstractJmsClient implements MeasurableClient {

    protected AtomicLong throughput = new AtomicLong(0);

    public AbstractJmsMeasurableClient(ConnectionFactory factory) {
        super(factory);
    }

    public void reset() {
        setThroughput(0);
    }

    public long getThroughput() {
        return throughput.get();
    }

    public void setThroughput(long val) {
        throughput.set(val);
    }

    public void incThroughput() {
        throughput.incrementAndGet();
    }

    public void incThroughput(long val) {
        throughput.addAndGet(val);
    }
}

==> activemq-parent-6.2.1-source-release.zip: activemq-parent-6.2.1/activemq-tooling/activemq-perf-maven-plugin/src/main/java/org/apache/activemq/tool/AbstractJmsMeasurableClient.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.tool;

import java.util.concurrent.atomic.AtomicLong;

import jakarta.jms.ConnectionFactory;

import org.apache.activemq.tool.sampler.MeasurableClient;

public abstract class AbstractJmsMeasurableClient extends AbstractJmsClient implements MeasurableClient {

    protected AtomicLong throughput = new AtomicLong(0);

    public AbstractJmsMeasurableClient(ConnectionFactory factory) {
        super(factory);
    }

    public void reset() {
        setThroughput(0);
    }

    public long getThroughput() {
        return throughput.get();
    }

    public void setThroughput(long val) {
        throughput.set(val);
    }

    public void incThroughput() {
        throughput.incrementAndGet();
    }

    public void incThroughput(long val) {
        throughput.addAndGet(val);
    }
}
